/*
 *        Delay functions for HI-TECH C on the PIC
 *
 *        Functions available:
 *                DelayUs(x)        Delay specified number of microseconds
 *                DelayMs(x)        Delay specified number of milliseconds
 *
 *        Note that there are range limits: x must not exceed 255 - for xtal
 *        frequencies > 12MHz the range for DelayUs is even smaller.
 *        To use DelayUs it is only necessary to include this file; to use
 *        DelayMs you must include delay.c in your project.
 *
 */

/*        Set the crystal frequency in the CPP predefined symbols list in
        HPDPIC, or on the PICC commmand line, e.g.
        picc -DXTAL_FREQ=4MHZ
        
        or
        picc -DXTAL_FREQ=100KHZ
        
        Note that this is the crystal frequency, the CPU clock is
        divided by 4.

 *        MAKE SURE this code is compiled with full optimization!!!
        
 */

#ifndef        XTAL_FREQ
#define        XTAL_FREQ        8                /* Crystal frequency in MHz */
#endif

#define        MHZ        *1000L                        /* number of kHz in a MHz */
#define        KHZ        *1                        /* number of kHz in a kHz */

#if        XTAL_FREQ >= 12

#define        DelayUs(x)        { unsigned char _dcnt; \
                          _dcnt = (x)*(XTAL_FREQ/12); \
                          while(--_dcnt != 0) \
                                  continue; }
#else

#define        DelayUs(x)        { unsigned char _dcnt; \
                          _dcnt = (x)/((12/XTAL_FREQ))|1; \
                          while(--_dcnt != 0) \
                                  continue; }
#endif

extern void DelayMs(unsigned char);
extern void DelaySec(char sec);
void Tempo_1mS(void);
void Tempo_XmS(unsigned int x);

unsigned char  N1;


void Tempo_XmS(unsigned int t)
{
  unsigned int t1;
  t1=t;
 while(t1>0)
 {
 Tempo_1mS();
 t1--;
 }
}


void Tempo_1mS()
{
asm{
       MOVLW 210 ;
       MOVWF _N1;   // 8 bit counter
 ici:
        nop ;   //1
        nop ;
        nop ;
        nop ;
        nop ;
        nop ;
        nop ;
        nop ;
        nop ;
        nop ; //10
        nop ;
        nop ;
        nop ;
        nop ;
        nop ;
        nop ; //16
        decfsz _N1 ,F ;   //decr counter, skip over next instruction if equal to zero
        bra ici   ;
        nop;
        nop;
        nop;
        nop;  // add 4x0.25=1S to round tempo pile poil to 500S
 } ;
 }